pub enum SqLiteDataStorageError {
SqlEngineError(Box<dyn Error + Sync + Send>),
DataConversionError(Box<dyn Error + Sync + Send>),
EpochIdOverflow(u64),
TimestampOverflow(u64),
}Available on crate feature
sqlite only.Expand description
SQLite data storage error.
Variants
SqlEngineError(Box<dyn Error + Sync + Send>)
SQLite error.
DataConversionError(Box<dyn Error + Sync + Send>)
Stored data is not compatible with the expected data type.
EpochIdOverflow(u64)
Epoch ID is too large to store in SQLite.
SQLite uses signed 64-bit integers, limiting epoch IDs to values up to 9,223,372,036,854,775,807.
TimestampOverflow(u64)
Timestamp is too large to store in SQLite.
SQLite uses signed 64-bit integers, limiting timestamps to values up to 9,223,372,036,854,775,807.