Extension

Struct Extension 

#[non_exhaustive]
pub struct Extension { pub extension_type: ExtensionType, pub extension_data: Vec<u8>, }
An MLS protocol extension.

Extensions are used as customization points in various parts of the MLS protocol and are inserted into an ExtensionList.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
extension_type: ExtensionType

Extension type of this extension

extension_data: Vec<u8>

Data held within this extension

Implementations

Source

impl Extension

pub fn new(extension_type: ExtensionType, extension_data: Vec<u8>) -> Extension

Create an extension with specified type and data properties.

pub fn extension_type(&self) -> ExtensionType

Extension type of this extension

pub fn extension_data(&self) -> &[u8]

Data held within this extension