pub struct ExportedTree<'a>(/* private fields */);Implementations
Sourceimpl<'a> ExportedTree<'a>
impl<'a> ExportedTree<'a>
pub fn to_bytes(&self) -> Result<Vec<u8>, MlsError>
pub fn byte_size(&self) -> usize
pub fn into_owned(self) -> ExportedTree<'static>
pub fn roster(&'a self) -> Roster<'a>
Sourcepub fn nodes(&self) -> &[Option<Node>]
pub fn nodes(&self) -> &[Option<Node>]
Returns a reference to the underlying vector of nodes in the tree.
Each element is None for a blank node, or Some(Node) for an
occupied leaf or parent node. Nodes are indexed by NodeIndex where
even indices are leaves and odd indices are parent nodes.
Sourcepub fn filtered_direct_path(
&self,
index: LeafIndex,
) -> Result<Vec<Option<&Parent>>, MlsError>
pub fn filtered_direct_path( &self, index: LeafIndex, ) -> Result<Vec<Option<&Parent>>, MlsError>
Returns the filtered direct path for a given leaf index as a vector
of Option<&Parent> nodes.
Per RFC 9420 Section 8.4, the filtered direct path removes all nodes
whose child on the copath has an empty resolution. Each entry is None
if the parent node at that position is blank, or Some(&Parent) if
it is populated.
Sourceimpl ExportedTree<'static>
impl ExportedTree<'static>
pub fn from_bytes(bytes: &[u8]) -> Result<Self, MlsError>